@@ -141,6 +141,27 @@ extern "C" {
  * @SPI_ROLE_AUTOCOMPLETE: The object is a dialog or list containing items for 
  *                         insertion into an entry widget, for instance a list 
  *                          of words for completion of a text entry.
+ * @SPI_ROLE_EDITBAR: The object is an editable text object in a toolbar
+ * @SPI_ROLE_EMBEDDED: The object is an embedded component container.  
+ *                     This role is a  "grouping" hint that the contained 
+ *                     objects share a context which is different from the 
+ *                     container in which this accessible is embedded.
+ *                     Uses: document embedding, "panel applets", etc.
+ * @SPI_ROLE_ENTRY: The object is a component whose textual content may be entered or modified by the user, provided @SPI_STATE_EDITABLE is present.
+ * @SPI_ROLE_CHART: The object is a graphical depiction of quantitative data. It may contain multiple subelements whose attributes and/or description may be queried to obtain both the quantitative data and information about how the data is being presented. The LABELLED_BY relation is particularly important in interpreting objects of this type, as is the accessible-description property.
+ * @SPI_ROLE_CAPTION: The object contains descriptive information, usually textual, about another user interface element such as a table, chart, or image.
+ * @SPI_ROLE_DOCUMENT_FRAME: The object is a visual frame or container which contains a view of document content. Document frames may occur within another Document instance, in which case the second document may be said to be embedded in the containing instance. HTML frames are often ROLE_DOCUMENT_FRAME. Either this object, or a singleton descendant, should implement the Document interface.
+ * @SPI_ROLE_HEADING: The object serves as a heading for content which follows it in a document. The 'heading level' of the heading, if availabe, may be obtained by querying the object's attributes.
+ * @SPI_ROLE_PAGE: The object is a containing instance which encapsulates a page of information. @SPI_ROLE_PAGE is used in documents and content which support a paginated navigation model.
+ * @SPI_ROLE_SECTION: The object is a containing instance of document content which constitutes a particular 'logical' section of the document. The type of content within a section, and the nature of the section division itself, may be obtained by querying the object's attributes. Sections may be nested.
+ * @SPI_ROLE_REDUNDANT_OBJECT: The object is redundant with another object in the hierarchy, and is exposed for purely technical reasons.  Objects of this role should normally be ignored by clients. 
+ * @SPI_ROLE_FORM: The object is a container for form controls, for instance as part of a 
+ * web form or user-input form within a document.  This role is primarily a tag/convenience for 
+ * clients when navigating complex documents, it is not expected that ordinary GUI containers will 
+ * always have ATK_ROLE_FORM.
+ * @SPI_ROLE_LINK: The object is a hypertext anchor.
+ * @SPI_ROLE_INPUT_METHOD_WINDOW: The object is an input method window used
+ * to input or compose a text character (typically a "complex text" character).
  * @SPI_ROLE_LAST_DEFINED: Used to determine the end of the role enumeration.
  *
  * Describes the role of an object
@@ -227,6 +248,19 @@ typedef enum
   SPI_ROLE_RULER,
   SPI_ROLE_APPLICATION,
   SPI_ROLE_AUTOCOMPLETE,
+  SPI_ROLE_EDITBAR,
+  SPI_ROLE_EMBEDDED,
+  SPI_ROLE_ENTRY,
+  SPI_ROLE_CHART,
+  SPI_ROLE_CAPTION,
+  SPI_ROLE_DOCUMENT_FRAME,
+  SPI_ROLE_HEADING,
+  SPI_ROLE_PAGE,
+  SPI_ROLE_SECTION,
+  SPI_ROLE_FORM,
+  SPI_ROLE_REDUNDANT_OBJECT,
+  SPI_ROLE_LINK,
+  SPI_ROLE_INPUT_METHOD_WINDOW,
   SPI_ROLE_LAST_DEFINED
 } AccessibleRole;
 
